<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="uk">
<context>
    <name>AboutDialog</name>
    <message>
        <location filename="../src/core/ui/about.cpp" line="34"/>
        <source>using Qt </source>
        <translation>використовує Qt </translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="41"/>
        <source>About</source>
        <translation>Про програму</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="42"/>
        <source>Thanks</source>
        <translation>Подяки</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="102"/>
        <source>It is a light and powerful application, written in Qt.</source>
        <translation>Це легка та потужна програма, що написана на Qt.</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="105"/>
        <source>Website</source>
        <translation>Вебсайт</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="109"/>
        <source>Licensed under the </source>
        <translation>За ліцензією </translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="43"/>
        <source>Help us</source>
        <translation>Допомога проекту</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="113"/>
        <source>Copyright &amp;copy; 2009-2013, Artem &apos;DOOMer&apos; Galichkin</source>
        <translation>Авторські права &amp;copy; 2009-2013, Артем &apos;DOOMer&apos; Галічкін</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="123"/>
        <source>What you can do?</source>
        <translation>Чим можна допомогти?</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="100"/>
        <source>is a crossplatform application for fast creating screenshots of your desktop.</source>
        <translation>ця мультиплатформова програма створена для швидкого отримання знімків Вашого робочого столу.</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="120"/>
        <source>You can join us and help us if you want. This is an invitation if you like this application.</source>
        <translation>Ви можете приєднатись і допомогти нам (якщо бажаєте). Відгукніться на це запрошення, якщо Вам сподобалась ця програма.</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="126"/>
        <source>Translate ScreenGrab to other languages</source>
        <translation>Перекласти ScreenGrab на інші мови</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="127"/>
        <source>Make suggestions for next releases</source>
        <translation>Надати побажання для майбутніх релізів</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="128"/>
        <source>Report bugs and issues</source>
        <translation>Повідомляти про помилки та несправну роботу</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="131"/>
        <source>Bug tracker</source>
        <translation>Баг-трекер</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="141"/>
        <source>Translate:</source>
        <translation>Переклади:</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="143"/>
        <source> Brazilian Portuguese translation</source>
        <translation> Бразильський португальський переклад</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="144"/>
        <source>Marcio Moraes</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="146"/>
        <source> Ukrainian translation</source>
        <translation> Український переклад</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="147"/>
        <source>Gennadi Motsyo</source>
        <translation>Генадій Моцьо</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="149"/>
        <source> Spanish translation</source>
        <translation> Іспанський переклад</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="150"/>
        <source>Burjans L García D</source>
        <translation>Гарсія Бурянс Д</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="152"/>
        <source> Italian translation</source>
        <translation> Італійський переклад</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="156"/>
        <source>Testing:</source>
        <translation>Тестування:</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="158"/>
        <source>Dual monitor support and other in Linux</source>
        <translation>Двомоніторну підтримку та інші тести в Linux</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="159"/>
        <source>Dual monitor support in Linux</source>
        <translation>Двомоніторну підтримку в Linux</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="160"/>
        <source>win32-build [Windows XP and 7]</source>
        <translation>win32-версії [Windows XP and 7]</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="161"/>
        <source>old win32-build [Windows Vista]</source>
        <translation>Ранні win32-версії [Windows Vista]</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="162"/>
        <source>win32-build [Windows 7]</source>
        <translation>win32-версії [Windows 7]</translation>
    </message>
</context>
<context>
    <name>ConfigDialog</name>
    <message>
        <location filename="../src/core/ui/configwidget.cpp" line="301"/>
        <source>Select directory</source>
        <translation>Вибір теки</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.cpp" line="212"/>
        <location filename="../src/core/ui/configwidget.cpp" line="313"/>
        <source>Warning</source>
        <translation>Попередження</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.cpp" line="211"/>
        <source>Directory %1 does not exist. Do you want to create it?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.cpp" line="312"/>
        <source>Do you want to reset the settings to the defaults?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.cpp" line="370"/>
        <source>Example: </source>
        <translation>Приклад: </translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.cpp" line="426"/>
        <source>This key is already used in your system! Please select another.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.cpp" line="432"/>
        <source>This key is already used in ScreenGrab! Please select another.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.cpp" line="450"/>
        <source>This key is not supported on your system!</source>
        <translation>Ця комбінація не підтримується вашою системою!</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.cpp" line="485"/>
        <source>Error</source>
        <translation>Помилка</translation>
    </message>
</context>
<context>
    <name>Core</name>
    <message>
        <location filename="../src/core/core.cpp" line="421"/>
        <source>Saved</source>
        <translation>Збережено</translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="443"/>
        <source>Name of saved file is copied to the clipboard</source>
        <translation>Ім&apos;я збереженого файлу скопійовано в буфер обміну </translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="471"/>
        <source>Copied</source>
        <translation>Скопійовано</translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="421"/>
        <source>Saved to </source>
        <translation>Збережено до</translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="63"/>
        <source>is a crossplatform application for fast creating screenshots of your desktop.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="67"/>
        <source>Take a fullscreen screenshot</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="71"/>
        <source>Take a screenshot of the active window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="75"/>
        <source>Take a screenshot of a selection of the screen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="79"/>
        <source>Run the application with a hidden main window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="449"/>
        <source>Path to saved file is copied to the clipboard</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="471"/>
        <source>Screenshot is copied to clipboard</source>
        <translation>Скріншот скопійовано до кишені</translation>
    </message>
</context>
<context>
    <name>DialogUploader</name>
    <message>
        <location filename="../src/modules/uploader/dialoguploader.ui" line="14"/>
        <source>Upload to internet</source>
        <translation>Завантажити в інтернет</translation>
    </message>
    <message>
        <location filename="../src/modules/uploader/dialoguploader.ui" line="22"/>
        <source>Upload to</source>
        <translation>Завантажити до</translation>
    </message>
    <message>
        <location filename="../src/modules/uploader/dialoguploader.ui" line="76"/>
        <source>Direct link:</source>
        <translation>Пряме посилання:</translation>
    </message>
    <message>
        <location filename="../src/modules/uploader/dialoguploader.ui" line="98"/>
        <location filename="../src/modules/uploader/dialoguploader.ui" line="189"/>
        <source>Open this link in the default web-browser</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/modules/uploader/dialoguploader.ui" line="101"/>
        <location filename="../src/modules/uploader/dialoguploader.ui" line="192"/>
        <source>Open</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/modules/uploader/dialoguploader.ui" line="114"/>
        <location filename="../src/modules/uploader/dialoguploader.ui" line="155"/>
        <source>Copy this link to the clipboard</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/modules/uploader/dialoguploader.ui" line="117"/>
        <location filename="../src/modules/uploader/dialoguploader.ui" line="158"/>
        <source>Copy</source>
        <translation>Копіювати</translation>
    </message>
    <message>
        <location filename="../src/modules/uploader/dialoguploader.ui" line="128"/>
        <source>Extended preformed html or bb codes:</source>
        <translation>Попередньо відформатований html та bb-код:</translation>
    </message>
    <message>
        <location filename="../src/modules/uploader/dialoguploader.ui" line="167"/>
        <source>Link to delete image:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/modules/uploader/dialoguploader.ui" line="300"/>
        <source>Upload</source>
        <translation>Завантажити</translation>
    </message>
    <message>
        <location filename="../src/modules/uploader/dialoguploader.ui" line="313"/>
        <source>Cancel</source>
        <translation>Відміна</translation>
    </message>
    <message>
        <location filename="../src/modules/uploader/dialoguploader.cpp" line="201"/>
        <location filename="../src/modules/uploader/dialoguploader.cpp" line="216"/>
        <source>Close</source>
        <translation>Закрити</translation>
    </message>
    <message>
        <location filename="../src/modules/uploader/dialoguploader.cpp" line="58"/>
        <source>Size: </source>
        <translation>Розмір:</translation>
    </message>
    <message>
        <location filename="../src/modules/uploader/dialoguploader.cpp" line="58"/>
        <source> pixel</source>
        <translation> піксель</translation>
    </message>
    <message>
        <location filename="../src/modules/uploader/dialoguploader.cpp" line="68"/>
        <source>Uploaded </source>
        <translation>Завантажено </translation>
    </message>
    <message>
        <location filename="../src/modules/uploader/dialoguploader.cpp" line="71"/>
        <location filename="../src/modules/uploader/dialoguploader.cpp" line="214"/>
        <source>Ready to upload</source>
        <translation>Готово до завантаження</translation>
    </message>
    <message>
        <location filename="../src/modules/uploader/dialoguploader.cpp" line="109"/>
        <source>Upload processing... Please wait</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/modules/uploader/dialoguploader.cpp" line="162"/>
        <source>Receiving a response from the server</source>
        <translation>Отримання відповіді від сервера</translation>
    </message>
    <message>
        <location filename="../src/modules/uploader/dialoguploader.cpp" line="179"/>
        <source>Upload completed</source>
        <translation>Завантаження завершено</translation>
    </message>
    <message>
        <location filename="../src/modules/uploader/dialoguploader.cpp" line="208"/>
        <source>Error uploading screenshot</source>
        <translation>Помилка завантаження скріншота</translation>
    </message>
    <message>
        <location filename="../src/modules/uploader/dialoguploader.cpp" line="209"/>
        <source>Error</source>
        <translation>Помилка</translation>
    </message>
    <message>
        <location filename="../src/modules/uploader/dialoguploader.cpp" line="246"/>
        <source>Open this link in your default web-browser, it may directly delete your uploaded image, without any warnings.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/modules/uploader/dialoguploader.cpp" line="247"/>
        <source>Are you sure you want to continue?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="355"/>
        <source>Screenshot </source>
        <translation>Скріншот </translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="70"/>
        <source>Quit</source>
        <translation>Вихід</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="65"/>
        <source>Save</source>
        <translation>Зберегти</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="64"/>
        <source>New</source>
        <translation>Новий</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="66"/>
        <source>Copy</source>
        <translation>Копіювати</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="359"/>
        <source>Double click to open screenshot in external default image viewer</source>
        <translation type="unfinished">Двойной клик откроет скриншот во внешнем вьювере изображений</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="368"/>
        <location filename="../src/core/ui/mainwindow.cpp" line="499"/>
        <source>Hide</source>
        <translation>Сховати вікно</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="69"/>
        <source>About</source>
        <translation>Про програму</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="67"/>
        <source>Options</source>
        <translation>Налаштування</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="157"/>
        <source>None</source>
        <translation>Немає</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="506"/>
        <source>Show</source>
        <translation>Показати вікно</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="558"/>
        <source>%1 Files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="581"/>
        <source>Save As...</source>
        <translation>Зберегти як...</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="14"/>
        <source>ScreenGrab</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="79"/>
        <source>Type:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="89"/>
        <source>Type of screenshot</source>
        <translation>Тип скріншоту</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="96"/>
        <source>Full screen</source>
        <translation>Весь екран</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="101"/>
        <source>Window</source>
        <translation>Вікно</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="106"/>
        <source>Screen area</source>
        <translation>Частина екрану</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="111"/>
        <source>Last selected area</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="141"/>
        <source>Delay:</source>
        <translation type="unfinished">Затримка:</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="203"/>
        <source>Zoom area around mouse</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="210"/>
        <source>No window decoration</source>
        <translation type="unfinished">Без декорацій вікна</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="217"/>
        <source>Include mouse pointer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="246"/>
        <source>toolBar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="154"/>
        <source>Delay in seconds before taking screenshot</source>
        <translation>Затримка в секундах перед отримання скріншоту</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="160"/>
        <source> sec</source>
        <translation> сек</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="68"/>
        <location filename="../src/core/ui/mainwindow.cpp" line="92"/>
        <source>Help</source>
        <translation>Довідка</translation>
    </message>
</context>
<context>
    <name>ModuleUploader</name>
    <message>
        <location filename="../src/modules/uploader/moduleuploader.cpp" line="41"/>
        <source>Upload the screenshot to the default image host</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/modules/uploader/moduleuploader.cpp" line="48"/>
        <source>Uploading</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <location filename="../src/core/regionselect.cpp" line="160"/>
        <source>Use your mouse to draw a rectangle to screenshot or exit pressing
any key or using the right or middle mouse buttons.</source>
        <translation>Використовуйте ліву клавішу мишки для виділення частини екрану.
Клавіатурні клавіші і права кнопка мишки відміняють режим виділення області.</translation>
    </message>
    <message>
        <location filename="../src/core/regionselect.cpp" line="192"/>
        <source>%1 x %2 pixels </source>
        <translation>%1 x %2 піксел </translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/modules/extedit/moduleextedit.cpp" line="38"/>
        <source>External edit</source>
        <translation>Зовнішнє редагування</translation>
    </message>
    <message>
        <location filename="../src/modules/extedit/moduleextedit.cpp" line="49"/>
        <source>Edit in...</source>
        <translation>Редагувати в...</translation>
    </message>
    <message>
        <location filename="../src/modules/uploader/moduleuploader.cpp" line="103"/>
        <source>Upload</source>
        <translation>Завантажити</translation>
    </message>
</context>
<context>
    <name>Uploader</name>
    <message>
        <location filename="../src/modules/uploader/uploader.cpp" line="225"/>
        <source>Direct link</source>
        <translation>Пряме посилання</translation>
    </message>
    <message>
        <location filename="../src/modules/uploader/uploader.cpp" line="228"/>
        <source>HTML code</source>
        <translation>HTML-код</translation>
    </message>
    <message>
        <location filename="../src/modules/uploader/uploader.cpp" line="231"/>
        <source>BB code</source>
        <translation>BB-код</translation>
    </message>
    <message>
        <location filename="../src/modules/uploader/uploader.cpp" line="234"/>
        <source>HTML code with thumb image</source>
        <translation>HTML-код з попереднім переглядом</translation>
    </message>
    <message>
        <location filename="../src/modules/uploader/uploader.cpp" line="237"/>
        <source>BB code with thumb image</source>
        <translation>BB-код з попереднім переглядом</translation>
    </message>
    <message>
        <location filename="../src/modules/uploader/uploader.cpp" line="240"/>
        <source>URl to delete image</source>
        <translation>URL для видалення зображення</translation>
    </message>
</context>
<context>
    <name>UploaderConfigWidget</name>
    <message>
        <location filename="../src/modules/uploader/uploaderconfigwidget.ui" line="24"/>
        <source>Common settings</source>
        <translation>Загальні налаштування</translation>
    </message>
    <message>
        <location filename="../src/modules/uploader/uploaderconfigwidget.ui" line="32"/>
        <source>Default image host</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/modules/uploader/uploaderconfigwidget.ui" line="44"/>
        <source>Always copy the link to the clipboard</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/modules/uploader/uploaderconfigwidget.ui" line="65"/>
        <source>Hosts settings</source>
        <translation>Налаштування сервісів</translation>
    </message>
    <message>
        <location filename="../src/modules/uploader/uploaderconfigwidget.ui" line="73"/>
        <source>Settings for: </source>
        <translation>Налаштування для:</translation>
    </message>
</context>
<context>
    <name>UploaderConfigWidget_ImgUr</name>
    <message>
        <location filename="../src/modules/uploader/imgur/uploaderconfigwidget_imgur.ui" line="20"/>
        <source>Configuration for imgur.com upload</source>
        <translation>Налаштування для завантаження на imgur.com</translation>
    </message>
    <message>
        <location filename="../src/modules/uploader/imgur/uploaderconfigwidget_imgur.ui" line="43"/>
        <source>No settings available right now</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Uploader_ImgUr_Widget</name>
    <message>
        <location filename="../src/modules/uploader/imgur/uploader_imgur_widget.ui" line="20"/>
        <source>Upload to Imgur</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>aboutWidget</name>
    <message>
        <location filename="../src/core/ui/aboutwidget.ui" line="128"/>
        <source>About Qt</source>
        <translation>Про Qt</translation>
    </message>
    <message>
        <location filename="../src/core/ui/aboutwidget.ui" line="154"/>
        <source>Close</source>
        <translation>Закрити</translation>
    </message>
</context>
<context>
    <name>configwidget</name>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="26"/>
        <location filename="../src/core/ui/configwidget.ui" line="627"/>
        <source>Options</source>
        <translation>Налаштування</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="192"/>
        <source>Default saving image format</source>
        <translation>Формат зображень за замовчанням</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="316"/>
        <source>Inserting current date time into saved filename</source>
        <translation>Вставка дати та часу в ім&apos;я файлу при збереженні</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="319"/>
        <source>Insert current date and time in file name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="366"/>
        <source>Autosave screenshot</source>
        <translation>Автозберігання скріншотів</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="378"/>
        <source>Save first screenshot</source>
        <translation>Зберігати перший скріншот</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="245"/>
        <source>Image quality</source>
        <translation>Якість картинки</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="251"/>
        <source>Image quality (1 - small file, 100 - high quality)</source>
        <translation>Якість картинки (1--меньшийрозмір файла, 100--найкраща якість)</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="387"/>
        <source>Allow run multiplies copy of ScreenGrab</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="400"/>
        <source>Enable external viewer</source>
        <translation>Дозволити зовнішній переглядач</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="407"/>
        <source>Fit to edges only inside selected screen area</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="410"/>
        <source>Fit to edges inside selected area</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="448"/>
        <source>Show ScreenGrab in the system tray</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="533"/>
        <source>Minimize to tray on click close button</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="536"/>
        <source>Minimize to tray when closing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="575"/>
        <source>Action</source>
        <translation>Дія</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="585"/>
        <source>Global shortcuts</source>
        <translation>Глобальні</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="592"/>
        <source>Fill screen</source>
        <translation>Весь екран</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="597"/>
        <source>Active window</source>
        <translation>Активне вікно</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="602"/>
        <source>Area select</source>
        <translation>Вибрану ділянку</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="608"/>
        <source>Local shortcuts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="612"/>
        <source>New screen</source>
        <translation>Новий скріншот</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="617"/>
        <source>Save screen</source>
        <translation>Зберегти скріншот</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="622"/>
        <source>Copy screen</source>
        <translation>Копіювати скріншот</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="632"/>
        <source>Help</source>
        <translation>Довідка</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="655"/>
        <source>Not defined</source>
        <translation>Не вибрана</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="77"/>
        <source>Main</source>
        <translation>Головні</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="87"/>
        <source>System tray</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="122"/>
        <source>Path to default selection dir for saving</source>
        <translation>Шлях до теки для збереження</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="135"/>
        <source>Browse filesystem</source>
        <translation>Огляд файлової системи</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="138"/>
        <source>Browse</source>
        <translation>Огляд</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="168"/>
        <source>Default filename</source>
        <translation>Вихідне ім&apos;я файлу</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="179"/>
        <source>Format</source>
        <translation>Формат</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="211"/>
        <source>Copy file name to the clipboard when saving</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="225"/>
        <source>Do not copy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="230"/>
        <source>Copy file name only</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="235"/>
        <source>Copy full file path</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="515"/>
        <source> sec</source>
        <translation> сек</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="82"/>
        <source>Advanced</source>
        <translation>Розширені</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="116"/>
        <source>Default save directory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="148"/>
        <source>Default file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="161"/>
        <source>Name:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="328"/>
        <source>Template: </source>
        <translation>Шаблон: </translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="353"/>
        <source>Example: </source>
        <translation>Приклад: </translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="363"/>
        <source>Automatically saving screenshots in grabbing process</source>
        <translation>Автоматичне збереження скріншотів при їх отриманні</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="457"/>
        <source>Tray messages:</source>
        <translation>Спливаючі повідомлення:</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="470"/>
        <source>Tray messages display mode</source>
        <translation>Режим відображення спливаючих повідомлень</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="474"/>
        <source>Never</source>
        <translation>Ніколи</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="479"/>
        <source>Tray mode</source>
        <translation>Якщо згорнуто</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="484"/>
        <source>Always</source>
        <translation>Завжди</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="92"/>
        <source>Shortcuts</source>
        <translation>Комбінації клавіш</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="390"/>
        <source>Allow multiple instances of ScreenGrab</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="397"/>
        <source>Open in external viewer on double click</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="580"/>
        <source>Shortcut</source>
        <translation>Клавіші</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="637"/>
        <source>Quit</source>
        <translation type="unfinished">Вихід</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="648"/>
        <source>Selected shortcut:</source>
        <translation>Вибрана комбінація:</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="496"/>
        <source>Time of display tray messages</source>
        <translation>Час показу спливаючих повідомлень</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="512"/>
        <source>Time to display tray messages</source>
        <translation>Час показу спливаючих повідомлень</translation>
    </message>
</context>
</TS>
